@@ -13,10 +13,35 @@ from ._util import public_name
 __all__ = ["CreateDjangoModel", "create_django_model"]
 
 
-@dc.dataclass
-class CreateDjangoModel:
+@dc.dataclass(frozen=True)
+class InspectDataclass:
     dataclass: type
 
+    def extract_meta(self) -> tuple[str | None, list[str] | None]:
+        pk_key, unique_together = None, None
+        if hasattr(self.dataclass, "Meta"):
+            meta = self.dataclass.Meta  # type: ignore
+            if hasattr(meta, "primary_key"):
+                pk_key = meta.primary_key
+                assert isinstance(pk_key, str)
+            if hasattr(meta, "unique_together"):
+                unique_together = meta.unique_together
+                assert isinstance(unique_together, list)
+
+        return pk_key, unique_together
+
+    def get_identifying_parameter(self) -> set[str]:
+        pk_key, unique_together = self.extract_meta()
+        res = set()
+        if pk_key is not None:
+            res.add(pk_key)
+        if unique_together is not None:
+            res.update(unique_together)
+        return res
+
+
+@dc.dataclass(frozen=True)
+class CreateDjangoModel(InspectDataclass):
     def __post_init__(self) -> None:
         # evaluate the Meta class
         pk_key, unique_together = self.extract_meta()
@@ -30,17 +55,6 @@ class CreateDjangoModel:
         django_model = type(self.dataclass.__name__, (models.Model,), fields)
         BACKEND_LINKER.link(self.dataclass, django_model)
 
-    def extract_meta(self) -> tuple[str | None, list[str] | None]:
-        pk_key, unique_together = None, None
-        if hasattr(self.dataclass, "Meta"):
-            meta = self.dataclass.Meta  # type: ignore
-            if hasattr(meta, "primary_key"):
-                pk_key = meta.primary_key
-            if hasattr(meta, "unique_together"):
-                unique_together = meta.unique_together
-
-        return pk_key, unique_together
-
     def translate_fields(
         self, pk_key: str | None
     ) -> "dict[str, models.Field[tp.Any, tp.Any]]":
