@@ -16,10 +16,9 @@ class DjangoStore:
     identifier: str
 
     def dump(self, dc_obj: tp.Any) -> tuple[models.Model, bool]:
-        model = django_model(dc_obj)
         kwgs, m2m = self.dataclass_to_django(dc_obj)
         identifying, defaults = self._split_of_pk(dc_obj, kwgs)
-        dj_obj, created = model.objects.using(self.identifier).update_or_create(
+        dj_obj, created = self.backend_manager(dc_obj).update_or_create(
             **identifying, defaults=defaults
         )
 
@@ -34,14 +33,12 @@ class DjangoStore:
         return dj_obj, created
 
     def load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> T:
-        model = django_model(dataclass)
-        instance = self.django_load(model, **filter_kwgs)
+        instance = self.django_load(dataclass, **filter_kwgs)
         return self.django_to_dataclass(instance)  # type: ignore
 
-    def django_load(
-        self, model: type[models.Model], **filter_kwgs: tp.Any
-    ) -> models.Model:
-        hits = model.objects.using(self.identifier).filter(**filter_kwgs).all()
+    def django_load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> models.Model:
+        manager = self.backend_manager(dataclass)
+        hits = manager.filter(**filter_kwgs).all()
         if len(hits) > 1:
             raise RuntimeError(
                 f"found {len(hits)} entries matching filter_kwgs {filter_kwgs}, be more specific!"
@@ -89,6 +86,11 @@ class DjangoStore:
             obj_kwgs[field.name] = val
         return dataclass(**obj_kwgs)
 
+    parse = django_to_dataclass
+
+    def backend_manager(self, dataclass: type[T]) -> tp.Any:
+        return django_model(dataclass).objects.using(self.identifier)
+
     @classmethod
     def _split_of_pk(
         cls, dc_obj: tp.Any, kwgs: dict[str, tp.Any]
