@@ -10,3 +10,9 @@ class BackendStoreProtocol(tp.Protocol):
 
     def load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> T:
         pass  # pragma: no cover
+
+    def parse(self, backend_obj: tp.Any) -> tp.Any:
+        pass  # pragma: no cover
+
+    def backend_manager(self, dataclass: type[T]) -> tp.Any:
+        pass  # pragma: no cover
