@@ -24,6 +24,24 @@ ACTIVE_STORES: collections.OrderedDict[
 def set_store(
     identifier: str = "first", flavor: str = "sqlite3", **kwgs: tp.Any
 ) -> None:
+    if identifier in ACTIVE_STORES:
+        raise RuntimeError(f"cannot set store {identifier}, because it is already set!")
+    if flavor == "sqlite3":
+        with django_setup(identifier) as databases:
+            assert identifier not in databases
+            databases[identifier] = dict(
+                NAME=kwgs["path"],
+                ENGINE="django.db.backends.sqlite3",
+                TIME_ZONE="UTC",
+                USE_TZ=True,
+            )
+            ACTIVE_STORES[identifier] = DjangoStore(identifier)
+    else:
+        raise NotImplementedError(flavor)
+
+
+@contextlib.contextmanager
+def django_setup(identifier: str) -> tp.Iterator[dict[str, tp.Any]]:
     if not settings.configured:
         settings.configure(
             DATABASES={"default": {"ENGINE": "django.db.backends.dummy"}},
@@ -35,33 +53,26 @@ def set_store(
 
     assert identifier != "default"
     databases = settings.DATABASES
-    if flavor == "sqlite3":
-        assert identifier not in databases
-        databases[identifier] = dict(
-            NAME=kwgs["path"],
-            ENGINE="django.db.backends.sqlite3",
-            TIME_ZONE="UTC",
-            USE_TZ=True,
-        )
-        ACTIVE_STORES[identifier] = DjangoStore(identifier)
-    else:
-        raise NotImplementedError(flavor)
-
+    yield databases
     new_apps = set(BACKEND_LINKER.app_labels) - set(settings.INSTALLED_APPS)
 
-    if not new_apps:
-        return
-    for app_label in BACKEND_LINKER.app_labels:
-        if app_label in new_apps:
-            settings.INSTALLED_APPS.append(app_label)
+    if new_apps:
+        for app_label in BACKEND_LINKER.app_labels:
+            if app_label in new_apps:
+                settings.INSTALLED_APPS.append(app_label)
+
+        apps.apps_ready = apps.models_ready = apps.loading = apps.ready = False
+        apps.clear_cache()
+        apps.populate(settings.INSTALLED_APPS)
+
+        try:
+            with contextlib.redirect_stdout(io.StringIO()):
+                call_command("makemigrations", "--noinput")
+        except SystemExit:
+            call_command("makemigrations")
 
-    apps.apps_ready = apps.models_ready = apps.loading = apps.ready = False
-    apps.clear_cache()
-    apps.populate(settings.INSTALLED_APPS)
     connections.configure_settings(databases)
-
     with contextlib.redirect_stdout(io.StringIO()):
-        call_command("makemigrations")
         call_command("migrate", database=identifier)
 
 
