@@ -2,6 +2,7 @@
 import contextlib
 import typing as tp
 
+from ._backend_manager_proxy import BackendManagerProxy
 from ._protocols import BackendStoreProtocol
 from ._protocols import T
 from ._store_setup import ACTIVE_STORES
@@ -29,6 +30,9 @@ class SyncStore:
     def load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> T:
         return self.impl.load(dataclass, **filter_kwgs)
 
+    def __getitem__(self, dataclass: type[T]) -> BackendManagerProxy:
+        return BackendManagerProxy(self.impl, self.impl.backend_manager(dataclass))
+
 
 store = SyncStore()
 
